==> qtjambi-qt3drender-6.2.9-sources.jar: io/qt/qt3d/render/QTextureDataUpdate.java <==
package io.qt.qt3d.render;


/**
 * <p>Holds content and information required to perform partial updates of a texture content</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qtexturedataupdate.html">Qt3DRender::QTextureDataUpdate</a></p>
 */
public class QTextureDataUpdate extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QTextureDataUpdate(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QTextureDataUpdate instance);
    
    public QTextureDataUpdate(io.qt.qt3d.render.QTextureDataUpdate other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QTextureDataUpdate instance, io.qt.qt3d.render.QTextureDataUpdate other);
    
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QTextureImageData data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QTextureImageData data_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QAbstractTexture.CubeMapFace face(){
        return io.qt.qt3d.render.QAbstractTexture.CubeMapFace.resolve(face_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int face_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int layer(){
        return layer_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int layer_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int mipLevel(){
        return mipLevel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int mipLevel_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.qt3d.render.QTextureDataUpdate rhs){
        return operator_equal_native_cref_Qt3DRender_QTextureDataUpdate(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rhs));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_cref_Qt3DRender_QTextureDataUpdate(long __this__nativeId, long rhs);
    
    @io.qt.QtUninvokable
    public final void setData(io.qt.qt3d.render.QTextureImageData data){
        setData_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), data);
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.render.QTextureImageData data);
    
    @io.qt.QtUninvokable
    public final void setFace(io.qt.qt3d.render.QAbstractTexture.CubeMapFace face){
        setFace_native_Qt3DRender_QAbstractTexture_CubeMapFace(QtJambi_LibraryUtilities.internal.nativeId(this), face.value());
    }
    
    @io.qt.QtUninvokable
    private native void setFace_native_Qt3DRender_QAbstractTexture_CubeMapFace(long __this__nativeId, int face);
    
    @io.qt.QtUninvokable
    public final void setLayer(int layer){
        setLayer_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), layer);
    }
    
    @io.qt.QtUninvokable
    private native void setLayer_native_int(long __this__nativeId, int layer);
    
    @io.qt.QtUninvokable
    public final void setMipLevel(int mipLevel){
        setMipLevel_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), mipLevel);
    }
    
    @io.qt.QtUninvokable
    private native void setMipLevel_native_int(long __this__nativeId, int mipLevel);
    
    @io.qt.QtUninvokable
    public final void setX(int x){
        setX_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), x);
    }
    
    @io.qt.QtUninvokable
    private native void setX_native_int(long __this__nativeId, int x);
    
    @io.qt.QtUninvokable
    public final void setY(int y){
        setY_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), y);
    }
    
    @io.qt.QtUninvokable
    private native void setY_native_int(long __this__nativeId, int y);
    
    @io.qt.QtUninvokable
    public final void setZ(int z){
        setZ_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), z);
    }
    
    @io.qt.QtUninvokable
    private native void setZ_native_int(long __this__nativeId, int z);
    
    @io.qt.QtUninvokable
    public final void swap(io.qt.qt3d.render.QTextureDataUpdate other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_Qt3DRender_QTextureDataUpdate(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_Qt3DRender_QTextureDataUpdate(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    public final int x(){
        return x_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int x_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int y(){
        return y_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int y_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int z(){
        return z_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int z_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTextureDataUpdate(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.qt3d.render.QTextureDataUpdate) {
            return operator_equal((io.qt.qt3d.render.QTextureDataUpdate) other);
        }

        return false;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    @Override
    public QTextureDataUpdate clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QTextureDataUpdate clone_native(long __this_nativeId);
}

==> qtjambi-qt3drender-6.3.5-sources.jar: io/qt/qt3d/render/QTextureDataUpdate.java <==
package io.qt.qt3d.render;


/**
 * <p>Holds content and information required to perform partial updates of a texture content</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qtexturedataupdate.html">Qt3DRender::QTextureDataUpdate</a></p>
 */
public class QTextureDataUpdate extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QTextureDataUpdate(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QTextureDataUpdate instance);
    
    public QTextureDataUpdate(io.qt.qt3d.render.QTextureDataUpdate other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QTextureDataUpdate instance, io.qt.qt3d.render.QTextureDataUpdate other);
    
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QTextureImageData data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QTextureImageData data_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QAbstractTexture.CubeMapFace face(){
        return io.qt.qt3d.render.QAbstractTexture.CubeMapFace.resolve(face_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int face_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int layer(){
        return layer_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int layer_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int mipLevel(){
        return mipLevel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int mipLevel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qpdfdocumentrenderoptions.html#operator-eq-eq-1">operator==(Qt3DRender::QTextureDataUpdate,Qt3DRender::QTextureDataUpdate)</a></p>
     */
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.qt3d.render.QTextureDataUpdate rhs){
        return operator_equal_native_cref_Qt3DRender_QTextureDataUpdate(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rhs));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_cref_Qt3DRender_QTextureDataUpdate(long __this__nativeId, long rhs);
    
    @io.qt.QtUninvokable
    public final void setData(io.qt.qt3d.render.QTextureImageData data){
        setData_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), data);
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.render.QTextureImageData data);
    
    @io.qt.QtUninvokable
    public final void setFace(io.qt.qt3d.render.QAbstractTexture.CubeMapFace face){
        setFace_native_Qt3DRender_QAbstractTexture_CubeMapFace(QtJambi_LibraryUtilities.internal.nativeId(this), face.value());
    }
    
    @io.qt.QtUninvokable
    private native void setFace_native_Qt3DRender_QAbstractTexture_CubeMapFace(long __this__nativeId, int face);
    
    @io.qt.QtUninvokable
    public final void setLayer(int layer){
        setLayer_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), layer);
    }
    
    @io.qt.QtUninvokable
    private native void setLayer_native_int(long __this__nativeId, int layer);
    
    @io.qt.QtUninvokable
    public final void setMipLevel(int mipLevel){
        setMipLevel_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), mipLevel);
    }
    
    @io.qt.QtUninvokable
    private native void setMipLevel_native_int(long __this__nativeId, int mipLevel);
    
    @io.qt.QtUninvokable
    public final void setX(int x){
        setX_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), x);
    }
    
    @io.qt.QtUninvokable
    private native void setX_native_int(long __this__nativeId, int x);
    
    @io.qt.QtUninvokable
    public final void setY(int y){
        setY_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), y);
    }
    
    @io.qt.QtUninvokable
    private native void setY_native_int(long __this__nativeId, int y);
    
    @io.qt.QtUninvokable
    public final void setZ(int z){
        setZ_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), z);
    }
    
    @io.qt.QtUninvokable
    private native void setZ_native_int(long __this__nativeId, int z);
    
    @io.qt.QtUninvokable
    public final void swap(io.qt.qt3d.render.QTextureDataUpdate other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_Qt3DRender_QTextureDataUpdate(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_Qt3DRender_QTextureDataUpdate(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    public final int x(){
        return x_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int x_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int y(){
        return y_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int y_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int z(){
        return z_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int z_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTextureDataUpdate(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.qt3d.render.QTextureDataUpdate) {
            return operator_equal((io.qt.qt3d.render.QTextureDataUpdate) other);
        }

        return false;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    @Override
    public QTextureDataUpdate clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QTextureDataUpdate clone_native(long __this_nativeId);
}
